==> kdepim4_4.14.10.orig.tar.xz: kdepim-4.14.10/libkdepim/addressline/autotests/baloocompletionemailtest.h <==
/*
  Copyright (c) 2015 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

*/

#ifndef BALOOCOMPLETIONEMAILTEST_H
#define BALOOCOMPLETIONEMAILTEST_H

#include <QObject>

class BalooCompletionEmailTest : public QObject
{
    Q_OBJECT
public:
    explicit BalooCompletionEmailTest(QObject *parent = 0);
    ~BalooCompletionEmailTest();

private Q_SLOTS:
    void returnEmptyListWhenEmailListIsEmpty();
    void shouldReturnSameListWhenNotExclude();
    void shouldReturnSameListIfBlackListDoesntInterceptEmail();
    void shouldReturnUniqueEmail();
    void shouldReturnEmptyListWhenAllBlackListed();
    void shouldExcludeDomain();
    void shouldReturnEmailListWhenDomainListIsNotNull();
    void shouldDontDuplicateEmailWhenUseCase();
    void shouldExcludeDuplicateEntryWithDisplayName();
    void shouldExcludeDuplicateEntryWithDisplayNameAddAddressWithDifferentCase();
    void shouldExcludeDuplicateEntryWithDifferentDisplayNameAddAddressWithDifferentCase();
};

#endif // BALOOCOMPLETIONEMAILTEST_H

==> kdepim-15.08.2.tar.xz: kdepim-15.08.2/libkdepim/addressline/autotests/baloocompletionemailtest.h <==
/*
  Copyright (c) 2015 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

*/

#ifndef BALOOCOMPLETIONEMAILTEST_H
#define BALOOCOMPLETIONEMAILTEST_H

#include <QObject>

class BalooCompletionEmailTest : public QObject
{
    Q_OBJECT
public:
    explicit BalooCompletionEmailTest(QObject *parent = Q_NULLPTR);
    ~BalooCompletionEmailTest();

private Q_SLOTS:
    void returnEmptyListWhenEmailListIsEmpty();
    void shouldReturnSameListWhenNotExclude();
    void shouldReturnSameListIfBlackListDoesntInterceptEmail();
    void shouldReturnUniqueEmail();
    void shouldReturnEmptyListWhenAllBlackListed();
    void shouldExcludeDomain();
    void shouldReturnEmailListWhenDomainListIsNotNull();
    void shouldDontDuplicateEmailWhenUseCase();
    void shouldExcludeDuplicateEntryWithDisplayName();
    void shouldExcludeDuplicateEntryWithDisplayNameAddAddressWithDifferentCase();
    void shouldExcludeDuplicateEntryWithDifferentDisplayNameAddAddressWithDifferentCase();
};

#endif // BALOOCOMPLETIONEMAILTEST_H
